@@ -30,7 +30,7 @@ class TestInitProxy(unittest.TestCase):
 
     def testinitproxy(self):
         from gi.repository import Gio
-        settings = Gio.Settings("com.ubuntu.update-manager")
+        settings = Gio.Settings.new("com.ubuntu.update-manager")
         detected_proxy = init_proxy(settings)
         self.assertEqual(detected_proxy, self.proxy)
 
